@@ -118,10 +118,6 @@ char *g_mime_message_get_date_as_string (GMimeMessage *message);
 void g_mime_message_set_message_id (GMimeMessage *message, const char *message_id);
 const char *g_mime_message_get_message_id (GMimeMessage *message);
 
-void g_mime_message_add_header (GMimeMessage *message, const char *header, const char *value);
-void g_mime_message_set_header (GMimeMessage *message, const char *header, const char *value);
-const char *g_mime_message_get_header (GMimeMessage *message, const char *header);
-
 GMimeObject *g_mime_message_get_mime_part (GMimeMessage *message);
 void g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part);
 
